Server Class (pysqueezecenter.player.Server)
============================================

The Server class deals with the SqueezeCenter server and provides the main
communication functions between the PySqueezeCenter API and the SqueezeCenter's
Telnet server.

.. autoclass:: pysqueezecenter.server.Server
   :members:
   :undoc-members:

